import type { VxeGridProps } from '#/adapter/vxe-table';
import type { DescItem } from '#/components/description';

import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'equId',
    label: '设备名称'
  },
  {
    component: 'RangePicker',
    fieldName: 'trialDate',
    label: '试产日期'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 100,
    fixed: 'left',
    slots: { default: 'equName' }
  },

  /* {
    title: '类型',
    slots: {
      // eslint-disable-next-line no-empty-pattern
      default: ({}) => {
        return <Tag color="cyan">试用</Tag>;
      }
    },
    minWidth: 80,
    fixed: 'left'
  },*/
  {
    title: '试产日期',
    field: 'trialDate',
    sortable: true,
    minWidth: 120
  },
  {
    title: '试产数量',
    field: 'trialNum',
    minWidth: 100
  },
  {
    title: '良品数量',
    field: 'proGoodNum',
    minWidth: 100
  },
  {
    title: '良品率',
    field: 'proGoodRate',
    minWidth: 100
  },
  {
    title: '计划运行时长',
    field: 'planRunTime',
    minWidth: 120
  },
  {
    title: '运行时长',
    field: 'runTime',
    minWidth: 100
  },
  {
    title: '停机时长',
    field: 'stopTime',
    minWidth: 100
  },
  {
    title: '调试履历',
    field: 'debugHistory',
    minWidth: 100
  },
  {
    title: '综合效率',
    field: 'oee',
    minWidth: 100
  },

  {
    title: '操作人',
    field: 'operatorName',
    minWidth: 100
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'trialId'
  },
  {
    component: 'Select',
    componentProps: {
      showSearch: true,
      allowClear: true,
      getPopupContainer
    },
    fieldName: 'equId',
    label: '设备名称'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'trialDate',
    label: '试产日期'
  },
  {
    component: 'Input',
    fieldName: 'trialNum',
    label: '试产数量'
  },
  {
    component: 'Input',
    fieldName: 'proGoodNum',
    label: '良品数量',
    help: '试产中产品合格数'
  },
  {
    component: 'Input',
    fieldName: 'proGoodRate',
    label: '良品率',
    help: '试产中产品合格率'
  },
  {
    component: 'TimePicker',
    componentProps: {
      format: 'HH:mm:ss',
      showTime: false,
      valueFormat: 'HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'startTime',
    label: '开始时间'
  },
  {
    component: 'TimePicker',
    componentProps: {
      format: 'HH:mm:ss',
      showTime: false,
      valueFormat: 'HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'endTime',
    label: '结束时间'
  },
  {
    component: 'TimePicker',
    componentProps: {
      format: 'HH:mm:ss',
      showTime: false,
      valueFormat: 'HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'planRunTime',
    label: '计划运行时长'
  },
  {
    component: 'TimePicker',
    componentProps: {
      format: 'HH:mm:ss',
      showTime: false,
      valueFormat: 'HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'runTime',
    label: '运行时长'
  },
  {
    component: 'TimePicker',
    componentProps: {
      format: 'HH:mm:ss',
      showTime: false,
      valueFormat: 'HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'stopTime',
    label: '停机时长'
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'debugHistory',
    label: '调试履历'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'operatorDept',
    label: '操作人部门',
    help: `试产操作人员所属部门`
    // rules: 'selectRequired',
  },
  {
    component: 'Select',
    componentProps: {
      allowClear: true,
      showSearch: true,
      getPopupContainer
    },
    fieldName: 'operatorId',
    label: '操作人',
    help: `试产操作人员`
  }
];

export const descSchema: DescItem[] = [
  {
    field: 'equName',
    label: '设备名称'
  },
  {
    field: 'oee',
    label: '综合效率'
  },
  {
    field: 'operatorName',
    label: '操作人'
  },
  {
    field: 'trialDate',
    label: '试产日期'
  },
  {
    field: 'trialNum',
    label: '试产数量'
  },
  {
    field: 'proGoodNum',
    label: '良品数量'
  },
  {
    field: 'proGoodRate',
    label: '良品率'
  },
  {
    field: 'startTime',
    label: '开始时间'
  },
  {
    field: 'endTime',
    label: '结束时间'
  },
  {
    field: 'planRunTime',
    label: '计划运行时长'
  },
  {
    field: 'runTime',
    label: '运行时长'
  },
  {
    field: 'stopTime',
    label: '停机时间'
  },
  {
    field: 'debugHistory',
    label: '设备履历'
  }
];
